################
Internal Classes
################
.. automodule:: holmium.core.pageobject 

.. autoclass:: ElementDict
.. autoclass:: ElementList
.. autoclass:: ElementGetter
.. autofunction:: enhanced

.. automodule:: holmium.core 

.. autoclass:: HolmiumNose
.. autoclass:: Config

